--
-- CalvesBox
--
-- @author  Flicher
-- @date  	13/04/14
--
-- @history	v1.0 - Initial implementation
--
--

CalvesBox = {};

function CalvesBox.prerequisitesPresent(specializations)
    return true;--SpecializationUtil.hasSpecialization(Fillable, specializations);
end;

function CalvesBox:load(xmlFile)
	-- Doors
	self.doors = {};
	
	self.doors.left = {};
	self.doors.left.animation = getXMLString(xmlFile, "vehicle.doors#leftAnimation");
	if self.doors.left.animation then 
		self.doors.left.rangeIndex = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.doors#leftRangeIndex"));
		self.doors.left.inRange = false;
		self.doors.left.isOpen = false;
		self.doors.left.dirtyFlag = self:getNextDirtyFlag();
	end;
	
	self.doors.right = {};
	self.doors.right.animation = getXMLString(xmlFile, "vehicle.doors#rightAnimation");
	if self.doors.right.animation then 
		self.doors.right.rangeIndex = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.doors#rightRangeIndex"));
		self.doors.right.inRange = false;
		self.doors.right.isOpen = false;
		self.doors.right.dirtyFlag = self:getNextDirtyFlag();
	end;
	
	self.doors.rear = {};
	self.doors.rear.animation = getXMLString(xmlFile, "vehicle.doors#rearAnimation");
	if self.doors.rear.animation then 
		self.doors.rear.rangeIndex = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.doors#rearRangeIndex"));
		self.doors.rear.inRange = false;
		self.doors.rear.isOpen = false;
		self.doors.rear.dirtyFlag = self:getNextDirtyFlag();
	end;

end;	
	
function CalvesBox:readStream(streamId, connection)
	
	self.doors.left.isOpen = streamReadBool(streamId);
	self.doors.right.isOpen = streamReadBool(streamId);
	self.doors.rear.isOpen = streamReadBool(streamId);
	
	if self.doors.left.animation ~= nil and self.playAnimation ~= nil then
		if self.doors.left.isOpen then
			self:playAnimation(self.doors.left.animation, 1, nil, true);
		end;
	end;
	
	if self.doors.right.animation ~= nil and self.playAnimation ~= nil then
		if self.doors.right.isOpen then
			self:playAnimation(self.doors.right.animation, 1, nil, true);
		end;
	end;
	
	if self.doors.rear.animation ~= nil and self.playAnimation ~= nil then
		if self.doors.rear.isOpen then
			self:playAnimation(self.doors.rear.animation, 1, nil, true);
		end;
	end;
end;

function CalvesBox:update(dt)

	if self.doors.left.rangeIndex then
		-- Manage key events for inrange door --
		if self.doors.left.inRange then
			if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then
				if self.doors.left.isOpen then
					if self.doors.left.animation ~= nil and self.playAnimation ~= nil then
						self:playAnimation(self.doors.left.animation, -1, nil);
					end;
				else
					if self.doors.left.animation ~= nil and self.playAnimation ~= nil then
						self:playAnimation(self.doors.left.animation, 1, nil);
					end;
				end;
				
				self.doors.left.isOpen = not self.doors.left.isOpen;
				self:raiseDirtyFlags(self.doors.left.dirtyFlag);
			end;
			-- Display key when in range --
			if self.doors.left.isOpen then
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("BJR_CLOSE_LEFT_PANEL")), InputBinding.IMPLEMENT_EXTRA2);
			else
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("BJR_OPEN_LEFT_PANEL")), InputBinding.IMPLEMENT_EXTRA2);
			end;
		end;
	end;
	
	if self.doors.right.rangeIndex then
		-- Manage key events for inrange door --
		if self.doors.right.inRange then
			if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then
				if self.doors.right.isOpen then
					if self.doors.right.animation ~= nil and self.playAnimation ~= nil then
						self:playAnimation(self.doors.right.animation, -1, nil);
					end;
				else
					if self.doors.right.animation ~= nil and self.playAnimation ~= nil then
						self:playAnimation(self.doors.right.animation, 1, nil);
					end;
				end;
				
				self.doors.right.isOpen = not self.doors.right.isOpen;
				self:raiseDirtyFlags(self.doors.right.dirtyFlag);
			end;
			-- Display key when in range --
			if self.doors.right.isOpen then
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("BJR_CLOSE_RIGHT_PANEL")), InputBinding.IMPLEMENT_EXTRA2);
			else
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("BJR_OPEN_RIGHT_PANEL")), InputBinding.IMPLEMENT_EXTRA2);
			end;
		end;
	end;
	
	if self.doors.rear.rangeIndex then
		-- Manage key events for inrange door --
		if self.doors.rear.inRange then
			if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then
				if self.doors.rear.isOpen then
					if self.doors.rear.animation ~= nil and self.playAnimation ~= nil then
						self:playAnimation(self.doors.rear.animation, -1, nil);
					end;
				else
					if self.doors.rear.animation ~= nil and self.playAnimation ~= nil then
						self:playAnimation(self.doors.rear.animation, 1, nil);
					end;
				end;
				
				self.doors.rear.isOpen = not self.doors.rear.isOpen;
				self:raiseDirtyFlags(self.doors.rear.dirtyFlag);
			end;
			-- Display key when in range --
			if self.doors.rear.isOpen then
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("BJR_CLOSE_REAR_DOOR")), InputBinding.IMPLEMENT_EXTRA2);
			else
				g_currentMission:addHelpButtonText(string.format(g_i18n:getText("BJR_OPEN_REAR_DOOR")), InputBinding.IMPLEMENT_EXTRA2);
			end;
		end;
	end;

end;

function CalvesBox:updateTick(dt)	
	if self.doors.left.rangeIndex then
		if g_currentMission.player ~= nil then
			-- Getting the distance between the player and the door
			local nearestDistance = 1.0; --max distance allowed
			local px, py, pz = getWorldTranslation(self.doors.left.rangeIndex);
			local vx, vy, vz = getWorldTranslation(g_currentMission.player.rootNode);
			local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);
			if distance < nearestDistance then
				self.doors.left.inRange = true;
			else
				self.doors.left.inRange = false;
			end;
		end;
	else
		self.doors.left.inRange = false;
	end;
	
	if self.doors.right.rangeIndex then
		if g_currentMission.player ~= nil then
			-- Getting the distance between the player and the door
			local nearestDistance = 1.0; --max distance allowed
			local px, py, pz = getWorldTranslation(self.doors.right.rangeIndex);
			local vx, vy, vz = getWorldTranslation(g_currentMission.player.rootNode);
			local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);
			if distance < nearestDistance then
				self.doors.right.inRange = true;
			else
				self.doors.right.inRange = false;
			end;
		end;
	else
		self.doors.right.inRange = false;
	end;
	
	if self.doors.rear.rangeIndex then
		if g_currentMission.player ~= nil then
			-- Getting the distance between the player and the door
			local nearestDistance = 1.0; --max distance allowed
			local px, py, pz = getWorldTranslation(self.doors.rear.rangeIndex);
			local vx, vy, vz = getWorldTranslation(g_currentMission.player.rootNode);
			local distance = Utils.vector3Length(px-vx, py-vy, pz-vz);
			if distance < nearestDistance then
				self.doors.rear.inRange = true;
			else
				self.doors.rear.inRange = false;
			end;
		end;
	else
		self.doors.rear.inRange = false;
	end;
end;

function CalvesBox:delete()
end;

function CalvesBox:mouseEvent(posX, posY, isDown, isUp, button)
end;

function CalvesBox:keyEvent(unicode, sym, modifier, isDown)
end;

function CalvesBox:draw()
end;